LocalPlatformInfoAdapter class

A PlatformInfoAdapter that actually acquires OS-specific information.

OSごとの情報を実際に取得するPlatformInfoAdapter。

Inheritance
Annotations

Constructors

LocalPlatformInfoAdapter()
A PlatformInfoAdapter that actually acquires OS-specific information.
const

Properties

debugImageData → Future<Uint8List?>
Get image for debugging.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isAndroid → bool
Check if the platform is Android.
no setteroverride
isDesktop → bool
Check if the platform is Desktop.
no setteroverride
isFuchsia → bool
Check if the platform is Fuchsia.
no setteroverride
isIOS → bool
Check if the platform is iOS.
no setteroverride
isLinux → bool
Check if the platform is Linux.
no setteroverride
isMacOS → bool
Check if the platform is macOS.
no setteroverride
isMobile → bool
Check if the platform is mobile.
no setteroverride
isTest → bool
Checks if it is under test.
no setterinherited
isWeb → bool
Check if the platform is Web.
no setteroverride
isWindows → bool
Check if the platform is Windows.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApplicationBuildNumber() → Future<String>
Get the application build number.
override
getApplicationDocumentsDirectory() → Future<Uri>
Get the application documents directory.
override
getApplicationId() → Future<String>
Get the application ID.
override
getApplicationVersion() → Future<String>
Get the application version.
override
getLibraryDirectory() → Future<Uri>
Get the library directory.
override
getTemporaryDirectory() → Future<Uri>
Get the temporary directory.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited